Staking Endpoints
=====================

ETH Staking account (USER_DATA)
-------------------------------
.. autofunction:: binance.spot.Spot.eth_staking_account

Get current ETH staking quota (USER_DATA)
-----------------------------------------
.. autofunction:: binance.spot.Spot.get_eth_staking_quota

Subscribe ETH Staking (TRADE)
-----------------------------
.. autofunction:: binance.spot.Spot.subscribe_eth_staking

Redeem ETH (TRADE)
------------------
.. autofunction:: binance.spot.Spot.redeem_eth

Wrap BETH (TRADE)
-----------------
.. autofunction:: binance.spot.Spot.wrap_beth

Get ETH staking history (USER_DATA)
-----------------------------------
.. autofunction:: binance.spot.Spot.get_eth_staking_history

Get ETH redemption history (USER_DATA)
--------------------------------------
.. autofunction:: binance.spot.Spot.get_eth_redemption_history

Get BETH rewards distribution history (USER_DATA) (USER_DATA)
-------------------------------------------------------------
.. autofunction:: binance.spot.Spot.get_beth_rewards_distribution_history

Get WBETH rewards history (USER_DATA)
-------------------------------------
.. autofunction:: binance.spot.Spot.get_wbeth_rewards_history

Get WBETH Rate History (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.get_wbeth_rate_history

Get WBETH wrap history (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.get_wbeth_wrap_history

Get WBETH unwrap history (USER_DATA)
------------------------------------
.. autofunction:: binance.spot.Spot.get_wbeth_unwrap_history
